var searchData=
[
  ['ogt_5fvox_5fimplementation_0',['OGT_VOX_IMPLEMENTATION',['../VoxToNanoVDB_8h.html#a0031fb357d0b150d6a64fb390720657f',1,'VoxToNanoVDB.h']]],
  ['openvdb_5fall_5ftree_5finstantiate_1',['OPENVDB_ALL_TREE_INSTANTIATE',['../version_8h_8in.html#af5d84e649a9214c7e60ef2fc79e9dcd3',1,'version.h.in']]],
  ['openvdb_5fapi_2',['OPENVDB_API',['../Platform_8h.html#a78ead02913edfee18be9d5982b788611',1,'Platform.h']]],
  ['openvdb_5fax_5fapi_3',['OPENVDB_AX_API',['../Platform_8h.html#a4054a06b412a2c4f17ad97328fccd2cd',1,'Platform.h']]],
  ['openvdb_5fax_5fexception_4',['OPENVDB_AX_EXCEPTION',['../ax_2openvdb__ax_2Exceptions_8h.html#a1a6edff4bc3fdd668d8d37381e74ea3c',1,'Exceptions.h']]],
  ['openvdb_5fcheck_5fgcc_5',['OPENVDB_CHECK_GCC',['../Platform_8h.html#a0059a19e8b0edca86629ef0f74e5b41a',1,'Platform.h']]],
  ['openvdb_5fdeprecated_6',['OPENVDB_DEPRECATED',['../Platform_8h.html#acad6915d4aac81665b540218e8b1e06c',1,'Platform.h']]],
  ['openvdb_5fdeprecated_5fmessage_7',['OPENVDB_DEPRECATED_MESSAGE',['../Platform_8h.html#ad1f8203a6a066b0312fd16e529bddd22',1,'Platform.h']]],
  ['openvdb_5fexact_5fis_5fapprox_5fequal_8',['OPENVDB_EXACT_IS_APPROX_EQUAL',['../Math_8h.html#a6b253af5feb78da3c382919eb161e94f',1,'Math.h']]],
  ['openvdb_5fexception_9',['OPENVDB_EXCEPTION',['../openvdb_2Exceptions_8h.html#a82231e85176ee365b2fe7ec5dae79830',1,'Exceptions.h']]],
  ['openvdb_5ffinish_5fnon_5fthreadsafe_5fstatic_5faddress_10',['OPENVDB_FINISH_NON_THREADSAFE_STATIC_ADDRESS',['../Platform_8h.html#a04a587fd9ae1911115d6c9ea3d7b2ecd',1,'Platform.h']]],
  ['openvdb_5ffinish_5fnon_5fthreadsafe_5fstatic_5freference_11',['OPENVDB_FINISH_NON_THREADSAFE_STATIC_REFERENCE',['../Platform_8h.html#a4c25fe5ebce981d186bc0d5b7094ec34',1,'Platform.h']]],
  ['openvdb_5ffinish_5fnon_5fthreadsafe_5fstatic_5fwrite_12',['OPENVDB_FINISH_NON_THREADSAFE_STATIC_WRITE',['../Platform_8h.html#a9154d689727e60526e308351485a8187',1,'Platform.h']]],
  ['openvdb_5ffinish_5fthreadsafe_5fstatic_5faddress_13',['OPENVDB_FINISH_THREADSAFE_STATIC_ADDRESS',['../Platform_8h.html#ae8027565fe483ff8ce9956b0c04de75c',1,'Platform.h']]],
  ['openvdb_5ffinish_5fthreadsafe_5fstatic_5freference_14',['OPENVDB_FINISH_THREADSAFE_STATIC_REFERENCE',['../Platform_8h.html#ac68bc3e353838aee46b122d1035467e8',1,'Platform.h']]],
  ['openvdb_5ffinish_5fthreadsafe_5fstatic_5fwrite_15',['OPENVDB_FINISH_THREADSAFE_STATIC_WRITE',['../Platform_8h.html#ac1bb06f94f61bbd95e69522ec6d184dd',1,'Platform.h']]],
  ['openvdb_5fhas_5fcxx11_16',['OPENVDB_HAS_CXX11',['../Platform_8h.html#ac3004d334cb9a9ac58f68c343220e571',1,'Platform.h']]],
  ['openvdb_5fhoudini_5fapi_17',['OPENVDB_HOUDINI_API',['../Platform_8h.html#a88b26daa45bbdd69d6bb12f9c7bfa3b2',1,'Platform.h']]],
  ['openvdb_5fimath_5fversion_18',['OPENVDB_IMATH_VERSION',['../version_8h_8in.html#a402e2478a133638ddb3b67454b884246',1,'version.h.in']]],
  ['openvdb_5finstantiate_19',['openvdb_instantiate',['../ExplicitInstantiation_8h.html#ae7babe623b8ad4e7e475f538816f8050',1,'OPENVDB_INSTANTIATE:&#160;ExplicitInstantiation.h'],['../version_8h_8in.html#ae7babe623b8ad4e7e475f538816f8050',1,'OPENVDB_INSTANTIATE:&#160;version.h.in']]],
  ['openvdb_5finstantiate_5fclass_20',['openvdb_instantiate_class',['../version_8h_8in.html#a442b05a4442dd035a1c03b9d940265df',1,'OPENVDB_INSTANTIATE_CLASS:&#160;version.h.in'],['../ExplicitInstantiation_8h.html#a442b05a4442dd035a1c03b9d940265df',1,'OPENVDB_INSTANTIATE_CLASS:&#160;ExplicitInstantiation.h']]],
  ['openvdb_5finstantiate_5fstruct_21',['openvdb_instantiate_struct',['../version_8h_8in.html#a16997c6054e446cc8ed613c9b027522d',1,'OPENVDB_INSTANTIATE_STRUCT:&#160;version.h.in'],['../ExplicitInstantiation_8h.html#a16997c6054e446cc8ed613c9b027522d',1,'OPENVDB_INSTANTIATE_STRUCT:&#160;ExplicitInstantiation.h']]],
  ['openvdb_5fis_5fpod_22',['OPENVDB_IS_POD',['../Math_8h.html#a76e004807bfa2a68739ea66b5f88c3ba',1,'Math.h']]],
  ['openvdb_5flibrary_5fabi_5fversion_5fstring_23',['OPENVDB_LIBRARY_ABI_VERSION_STRING',['../version_8h_8in.html#a272bfcd1c61e4da085256e85e3af8dc8',1,'version.h.in']]],
  ['openvdb_5flibrary_5fmajor_5fversion_5fnumber_24',['OPENVDB_LIBRARY_MAJOR_VERSION_NUMBER',['../version_8h_8in.html#ab04cca0a808617a2145460fc13d77534',1,'version.h.in']]],
  ['openvdb_5flibrary_5fminor_5fversion_5fnumber_25',['OPENVDB_LIBRARY_MINOR_VERSION_NUMBER',['../version_8h_8in.html#a998b52f43bf6f90248e86ce19814a22e',1,'version.h.in']]],
  ['openvdb_5flibrary_5fpatch_5fversion_5fnumber_26',['OPENVDB_LIBRARY_PATCH_VERSION_NUMBER',['../version_8h_8in.html#ac0c88b27e16ed63fa759b577f290e7e8',1,'version.h.in']]],
  ['openvdb_5flibrary_5fversion_5fnumber_27',['OPENVDB_LIBRARY_VERSION_NUMBER',['../version_8h_8in.html#a42d8e4a1da2a0d797b1382579095055a',1,'version.h.in']]],
  ['openvdb_5flibrary_5fversion_5fstring_28',['OPENVDB_LIBRARY_VERSION_STRING',['../version_8h_8in.html#a473ea1fceaac55f6e7766789543e2259',1,'version.h.in']]],
  ['openvdb_5flog_29',['OPENVDB_LOG',['../logging_8h.html#aa330e4039ae78342810adc99f391bbf2',1,'logging.h']]],
  ['openvdb_5flog_5fdebug_30',['OPENVDB_LOG_DEBUG',['../logging_8h.html#abc3f222c3f229a5447085e6ee867af13',1,'logging.h']]],
  ['openvdb_5flog_5fdebug_5fruntime_31',['OPENVDB_LOG_DEBUG_RUNTIME',['../logging_8h.html#abdcf8b979065a205aaa7492d3aec79e6',1,'logging.h']]],
  ['openvdb_5flog_5ferror_32',['OPENVDB_LOG_ERROR',['../logging_8h.html#a46b2f70df6eb9ea3f1313bdaa610693a',1,'logging.h']]],
  ['openvdb_5flog_5ffatal_33',['OPENVDB_LOG_FATAL',['../logging_8h.html#a743e36b29932fefe6fd87519d85fdce2',1,'logging.h']]],
  ['openvdb_5flog_5finfo_34',['OPENVDB_LOG_INFO',['../logging_8h.html#a613aa93b2e98f1b56e66f731bf6928ec',1,'logging.h']]],
  ['openvdb_5flog_5fwarn_35',['OPENVDB_LOG_WARN',['../logging_8h.html#a5a55a6912fba67df50a02fd549bea63f',1,'logging.h']]],
  ['openvdb_5fno_5fdeprecation_5fwarning_5fbegin_36',['OPENVDB_NO_DEPRECATION_WARNING_BEGIN',['../Platform_8h.html#a6cc94924e47acd6586e2f5e6c3330768',1,'Platform.h']]],
  ['openvdb_5fno_5fdeprecation_5fwarning_5fend_37',['OPENVDB_NO_DEPRECATION_WARNING_END',['../Platform_8h.html#a0c70c8f354f37e782bf75458027eaeca',1,'Platform.h']]],
  ['openvdb_5fno_5ffp_5fequality_5fwarning_5fbegin_38',['OPENVDB_NO_FP_EQUALITY_WARNING_BEGIN',['../Math_8h.html#aa07e40c3d7f010bcb5c1369f6a78c8b0',1,'Math.h']]],
  ['openvdb_5fno_5ffp_5fequality_5fwarning_5fend_39',['OPENVDB_NO_FP_EQUALITY_WARNING_END',['../Math_8h.html#a97049404e8b5906163c092580a6d394a',1,'Math.h']]],
  ['openvdb_5fno_5ftype_5fconversion_5fwarning_5fbegin_40',['OPENVDB_NO_TYPE_CONVERSION_WARNING_BEGIN',['../Platform_8h.html#a4f7375e7791cade4ae486a8ebb68056f',1,'Platform.h']]],
  ['openvdb_5fno_5ftype_5fconversion_5fwarning_5fend_41',['OPENVDB_NO_TYPE_CONVERSION_WARNING_END',['../Platform_8h.html#ac13c11880cf8b8dd311a72e5a05b295d',1,'Platform.h']]],
  ['openvdb_5fno_5funreachable_5fcode_5fwarning_5fbegin_42',['OPENVDB_NO_UNREACHABLE_CODE_WARNING_BEGIN',['../Platform_8h.html#ac8dadf7b858eb1987194e570f80bff79',1,'Platform.h']]],
  ['openvdb_5fno_5funreachable_5fcode_5fwarning_5fend_43',['OPENVDB_NO_UNREACHABLE_CODE_WARNING_END',['../Platform_8h.html#aa4a2916120921a779c15e6182c8d8118',1,'Platform.h']]],
  ['openvdb_5fnumeric_5ftree_5finstantiate_44',['OPENVDB_NUMERIC_TREE_INSTANTIATE',['../version_8h_8in.html#a392f57a6af5cdf543083e2b34652763c',1,'version.h.in']]],
  ['openvdb_5fpackage_5frevision_45',['OPENVDB_PACKAGE_REVISION',['../version_8h_8in.html#a45d92b7b2794bdecd50c965b7b7b0431',1,'version.h.in']]],
  ['openvdb_5fpackage_5furl_46',['OPENVDB_PACKAGE_URL',['../version_8h_8in.html#a793527036c5dff66a22d69059c129349',1,'version.h.in']]],
  ['openvdb_5fpreproc_5fconcat_47',['OPENVDB_PREPROC_CONCAT',['../Platform_8h.html#aa36b3655c9a79f24e58ec8b8f73cae65',1,'Platform.h']]],
  ['openvdb_5fpreproc_5fstringify_48',['OPENVDB_PREPROC_STRINGIFY',['../Platform_8h.html#a2a4ca104e8d5858d3ca984fe99f2b1df',1,'Platform.h']]],
  ['openvdb_5freal_5ftree_5finstantiate_49',['OPENVDB_REAL_TREE_INSTANTIATE',['../version_8h_8in.html#a5ab371d0dbfa33fb93da47de4fbbb780',1,'version.h.in']]],
  ['openvdb_5fstart_5fnon_5fthreadsafe_5fstatic_5faddress_50',['OPENVDB_START_NON_THREADSAFE_STATIC_ADDRESS',['../Platform_8h.html#a7576930a67c5438495f5b4eca806a209',1,'Platform.h']]],
  ['openvdb_5fstart_5fnon_5fthreadsafe_5fstatic_5freference_51',['OPENVDB_START_NON_THREADSAFE_STATIC_REFERENCE',['../Platform_8h.html#a1de5e38ab3511d8aa63ff49be1703a3c',1,'Platform.h']]],
  ['openvdb_5fstart_5fnon_5fthreadsafe_5fstatic_5fwrite_52',['OPENVDB_START_NON_THREADSAFE_STATIC_WRITE',['../Platform_8h.html#ac303d44a9c746b4fc7882bb57ef4c0e2',1,'Platform.h']]],
  ['openvdb_5fstart_5fthreadsafe_5fstatic_5faddress_53',['OPENVDB_START_THREADSAFE_STATIC_ADDRESS',['../Platform_8h.html#aba3a523e76beaaf0d8cc51e8bbdbe8ae',1,'Platform.h']]],
  ['openvdb_5fstart_5fthreadsafe_5fstatic_5freference_54',['OPENVDB_START_THREADSAFE_STATIC_REFERENCE',['../Platform_8h.html#a116c03460d08a7c8124d77f0025aa5d6',1,'Platform.h']]],
  ['openvdb_5fstart_5fthreadsafe_5fstatic_5fwrite_55',['OPENVDB_START_THREADSAFE_STATIC_WRITE',['../Platform_8h.html#a7b933d956cd2f602c346ec80f34d7efa',1,'Platform.h']]],
  ['openvdb_5ftarget_5fbits_56',['OPENVDB_TARGET_BITS',['../openvdb_2Types_8h.html#a316dac43d38af596402b6e2204476e16',1,'Types.h']]],
  ['openvdb_5ftemplate_5fexport_57',['OPENVDB_TEMPLATE_EXPORT',['../Platform_8h.html#ac696e2eebc7f22c46fdcf87f8ecebd8c',1,'Platform.h']]],
  ['openvdb_5ftemplate_5fimport_58',['OPENVDB_TEMPLATE_IMPORT',['../Platform_8h.html#ae90ddc631630096e31703b376e7bc04d',1,'Platform.h']]],
  ['openvdb_5fthreadsafe_5fstatic_5faddress_59',['OPENVDB_THREADSAFE_STATIC_ADDRESS',['../Platform_8h.html#a4221a82a55c24552c9b9812961654b94',1,'Platform.h']]],
  ['openvdb_5fthreadsafe_5fstatic_5freference_60',['OPENVDB_THREADSAFE_STATIC_REFERENCE',['../Platform_8h.html#af45bfee6bdac4fd25ebba777d6ae8609',1,'Platform.h']]],
  ['openvdb_5fthreadsafe_5fstatic_5fwrite_61',['OPENVDB_THREADSAFE_STATIC_WRITE',['../Platform_8h.html#a74544cfe36b32ed0637ff78e5b26e19e',1,'Platform.h']]],
  ['openvdb_5fthrow_62',['OPENVDB_THROW',['../openvdb_2Exceptions_8h.html#a3eec2ef3138c64fc5844490187c1b8d1',1,'Exceptions.h']]],
  ['openvdb_5fubsan_5fsuppress_63',['OPENVDB_UBSAN_SUPPRESS',['../Platform_8h.html#a75f69f6aab6d38a8269686d79b268b29',1,'Platform.h']]],
  ['openvdb_5fuse_5fblosc_64',['OPENVDB_USE_BLOSC',['../version_8h_8in.html#ad9b4094c98dfe2c5e327e97640573397',1,'version.h.in']]],
  ['openvdb_5fuse_5fdelayed_5floading_65',['OPENVDB_USE_DELAYED_LOADING',['../version_8h_8in.html#a37848ce33ebef26696a36d9975a1fe1a',1,'version.h.in']]],
  ['openvdb_5fuse_5fexplicit_5finstantiation_66',['OPENVDB_USE_EXPLICIT_INSTANTIATION',['../version_8h_8in.html#a9ae309f5f7e4f0e48703fdf3fd0a1df1',1,'version.h.in']]],
  ['openvdb_5fuse_5fimath_5fhalf_67',['OPENVDB_USE_IMATH_HALF',['../version_8h_8in.html#afd09230e7f8a44c7b990c2d64326b6d5',1,'version.h.in']]],
  ['openvdb_5fuse_5fversion_5fnamespace_68',['OPENVDB_USE_VERSION_NAMESPACE',['../version_8h_8in.html#a2dde157791cd7558cdf886489256ba14',1,'version.h.in']]],
  ['openvdb_5fuse_5fzlib_69',['OPENVDB_USE_ZLIB',['../version_8h_8in.html#a729c4c59a11263debb7250fd2646315c',1,'version.h.in']]],
  ['openvdb_5fvec3_5ftree_5finstantiate_70',['OPENVDB_VEC3_TREE_INSTANTIATE',['../version_8h_8in.html#a7d027e8f99ea64bd389bf3015fe6eada',1,'version.h.in']]],
  ['openvdb_5fversion_5fhas_5fbeen_5fincluded_71',['OPENVDB_VERSION_HAS_BEEN_INCLUDED',['../version_8h_8in.html#adcaf61d21377593c0e9dad4a0206bb97',1,'version.h.in']]],
  ['openvdb_5fversion_5fname_72',['OPENVDB_VERSION_NAME',['../version_8h_8in.html#a00be3835cb8ad1ded8abd821fad20fc0',1,'version.h.in']]],
  ['openvdb_5fvolume_5ftree_5finstantiate_73',['OPENVDB_VOLUME_TREE_INSTANTIATE',['../version_8h_8in.html#a9ae6309f0451d550fc854cf97c4b4221',1,'version.h.in']]]
];
